summaryrefslogtreecommitdiff
path: root/lib/Log/Any/Adapter/Callback.pm
diff options
context:
space:
mode:
Diffstat (limited to 'lib/Log/Any/Adapter/Callback.pm')
-rw-r--r--lib/Log/Any/Adapter/Callback.pm58
1 files changed, 41 insertions, 17 deletions
diff --git a/lib/Log/Any/Adapter/Callback.pm b/lib/Log/Any/Adapter/Callback.pm
index a9c5fa2..6074052 100644
--- a/lib/Log/Any/Adapter/Callback.pm
+++ b/lib/Log/Any/Adapter/Callback.pm
@@ -1,16 +1,16 @@
package Log::Any::Adapter::Callback;
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-01-14'; # DATE
-our $DIST = 'Log-Any-Adapter-Callback'; # DIST
-our $VERSION = '0.101'; # VERSION
-
use strict;
use warnings;
use Log::Any::Adapter::Util qw(make_method);
use base qw(Log::Any::Adapter::Base);
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2023-11-21'; # DATE
+our $DIST = 'Log-Any-Adapter-Callback'; # DIST
+our $VERSION = '0.102'; # VERSION
+
my @logging_methods = Log::Any->logging_methods;
my %logging_levels;
for my $i (0..@logging_methods-1) {
@@ -60,7 +60,7 @@ for my $method (Log::Any->detection_methods()) {
}
1;
# ABSTRACT: (DEPRECATED) Send Log::Any logs to a subroutine
__END__
@@ -70,11 +70,11 @@ __END__
=head1 NAME
-Log::Any::Adapter::Callback - (DEPRECATED) Send Log::Any logs to a subroutine
+Log::Any::Adapter::Callback - (DEPRECATED)(ADOPTME) Send Log::Any logs to a subroutine
=head1 VERSION
-This document describes version 0.101 of Log::Any::Adapter::Callback (from Perl distribution Log-Any-Adapter-Callback), released on 2020-01-14.
+This document describes version 0.102 of Log::Any::Adapter::Callback (from Perl distribution Log-Any-Adapter-Callback), released on 2023-11-21.
=head1 SYNOPSIS
@@ -124,14 +124,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Log-Any-Ad
Source repository is at L<https://github.com/perlancar/perl-Log-Any-Adapter-Callback>.
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Log-Any-Adapter-Callback>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
=head1 SEE ALSO
L<Log::Any::Adapter::Capture>
@@ -142,11 +134,43 @@ L<Log::Any>
perlancar <perlancar@cpan.org>
+=head1 CONTRIBUTOR
+
+=for stopwords Steven Haryanto
+
+Steven Haryanto <stevenharyanto@gmail.com>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
=head1 COPYRIGHT AND LICENSE
-This software is copyright (c) 2020, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2023, 2020, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Log-Any-Adapter-Callback>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
=cut
@@ -60,7 +60,7 @@ for my $method (Log::Any->detection_methods()) {
}
1;
-# ABSTRACT: (DEPRECATED) Send Log::Any logs to a subroutine
+# ABSTRACT: (DEPRECATED)(ADOPTME) Send Log::Any logs to a subroutine
__END__